@@ -733,6 +733,7 @@ tp = InstructionTape()
 tr_int = TrackedReal(v_int, d, tp)
 tr_float = TrackedReal(v_float, d, tp)
 tr_float2 = TrackedReal(v_float2, d2, tp)
+tr_float32 = TrackedReal(Float32(v_float), Float32(d), tp)
 
 @test hash(tr_float) === hash(v_float)
 @test hash(tr_float, hash(1)) === hash(v_float, hash(1))
@@ -756,6 +757,11 @@ tr_rand = rand(MersenneTwister(1), TrackedReal{Int,Float64,Nothing})
 @test eps(tr_float) === eps(v_float)
 @test eps(typeof(tr_float)) === eps(Float64)
 
+@test floatmin(typeof(tr_float)) === floatmin(Float64)
+@test floatmin(typeof(tr_float32)) === floatmin(Float32)
+@test floatmax(typeof(tr_float)) === floatmax(Float64)
+@test floatmax(typeof(tr_float32)) === floatmax(Float32)
+
 @test floor(tr_float) === floor(v_float)
 @test floor(Int, tr_float) === floor(Int, v_float)
 
